[Swift-commit] r2855 - SwiftApps/SIDGrid/swift/projects/andric/peakfit_pilots/PK2

noreply at svn.ci.uchicago.edu noreply at svn.ci.uchicago.edu
Sun Apr 12 10:59:28 CDT 2009


Author: andric
Date: 2009-04-12 10:59:27 -0500 (Sun, 12 Apr 2009)
New Revision: 2855

Modified:
   SwiftApps/SIDGrid/swift/projects/andric/peakfit_pilots/PK2/PK2.swift
Log:
created new peakfit types

Modified: SwiftApps/SIDGrid/swift/projects/andric/peakfit_pilots/PK2/PK2.swift
===================================================================
--- SwiftApps/SIDGrid/swift/projects/andric/peakfit_pilots/PK2/PK2.swift	2009-04-09 23:51:15 UTC (rev 2854)
+++ SwiftApps/SIDGrid/swift/projects/andric/peakfit_pilots/PK2/PK2.swift	2009-04-12 15:59:27 UTC (rev 2855)
@@ -1,35 +1,38 @@
 #----  doing peakfit on PK2 pilot subject
 type file{}
-
+type Rscript;
+type PeakfitR{
+    Rscript ShellpeakPK2runbyrun;
+    Rscript preprocessEnewsmooth;
+    Rscript peakfitv2v1;
+}
 type PeakResult{
     file pdf;
     file a;
     file b;
 }
 
-app (PeakResult outObj) peakScript (file scriptFile, file tsfile, file preprocR, file peakfitR){
-    RInvoke @filename(scriptFile) @filename(tsfile) @filename(outObj);
+
+app (PeakResult outObj) peakScript (PeakfitR code, file tsfile){
+    RInvoke @code.ShellpeakPK2runbyrun @filename(tsfile) @filename(outObj);
 }
 
+PeakfitR code<simple_mapper; location="peak_scriptsV2", suffix=".R">;
 
-file script<"peak_scripts/Shellpeak_PK2runbyrun.R">;
-file preprocR<"peak_scripts/preprocess.Enewsmooth.R">;
-file peakfitR<"peak_scripts/peakfit_2.1.R">;
+string declarelist[] = ["PK2"];
+int runs[] = [1:8];
+string hemilist[] = ["lh"];
+int inputRegionNo[] = [54];
 
-string declarelist[] = ["PK2"];
 foreach subject in declarelist{
-    int runs[] = [1:8];
     foreach rn in runs{
-        string hemilist[] = ["lh","rh"];
         foreach h in hemilist{
-            int inputRegionNo[] = [15,33,34,60];
             foreach rr in inputRegionNo{
-                string project_dir=@strcat("/disks/ci-gpfs/fmri/cnari/swift/projects/andric/peakfit_pilots/",subject);
                 ## map inputs
-                file inFile<single_file_mapper; file=@strcat(project_dir,"/input/",subject,"_peakTS_data",h,".",rr,"run",rn)>;
+                file inFile<single_file_mapper; file=@strcat("input/",subject,"_peakTS_data",h,".",rr,"run",rn)>;
                 ## map results
-                PeakResult outObj<simple_mapper; prefix=@strcat(subject,".",rr,"_",h,"run",rn,".result.")>;
-                (outObj)=peakScript(script,inFile, preprocR, peakfitR);
+                PeakResult outObj<simple_mapper; location="results", prefix=@strcat(subject,".",rr,"_",h,"run",rn,".result.")>;
+                outObj=peakScript(code, inFile);
             }
         }
     }
@@ -1,35 +1,38 @@
-#----  doing peakfit on PK2 pilot subject
+#----  doing peakfit on PK2 pilot subject and experimenting with code
 type file{}




More information about the Swift-commit mailing list